searchNodes=[{"doc":"A library to work with tagged tuples. Tagged tuple is a tuple attaching a tag to a value {tag, value} . Common tagged tuples are {:ok, value} and {:error, message} returned from the functions. Tag chains A chain of tags can be attached to a single core value by nesting tagged tuples in each other. For example, {:units, {:boxes, 1}} and {:units, {:kilograms, 2.5}} tagged tuples describe the same deliverable item with different measures. The tag chains of :units - :boxes and :units - :kilograms can be efficiently pattern matched then to handle core values of different types appropriately.","ref":"TaggedTuple.html","title":"TaggedTuple","type":"module"},{"doc":"Defines a tagged tuple. It's equivalent to {tag, value} . The operator is right-associative. When it's called several times in a row, it assembles a tag chain with a value in the core. :x -- - :y -- - :z -- - &quot;value&quot; == { :x , { :y , { :z , &quot;value&quot; } } } Can be used in Expressions and Pattern Matchings. Examples iex&gt; use TaggedTuple ...&gt; :tag -- - 12 { :tag , 12 } ...&gt; tagged_tuple = :a -- - :tag -- - :chain -- - 12 { :a , { :tag , { :chain , 12 } } } ...&gt; match? ( :a -- - :tag -- - _tail , tagged_tuple ) true ...&gt; :a -- - t1 -- - t2 -- - core_value = tagged_tuple ...&gt; t1 == :tag ...&gt; t2 == :chain ...&gt; core_value == 12","ref":"TaggedTuple.html#---/2","title":"TaggedTuple.---/2","type":"macro"},{"doc":"Converts a list to a tagged tuple. The list must have at least two elements, a tag and a value, respectfully. The tag_fun will be invoked with each tag, and the result will be added to the tuple. The value_fun will be invoked with the core value, and the result will be added to the tuple. Examples iex&gt; TaggedTuple . from_list ( [ :a , :tag , :chain , 2 ] ) { :a , { :tag , { :chain , 2 } } } iex&gt; TaggedTuple . from_list ( [ &quot;a&quot; , &quot;tag&quot; , &quot;chain&quot; , 200 ] , &amp; String . to_existing_atom / 1 , &amp; div ( &amp;1 , 100 ) ) { :a , { :tag , { :chain , 2 } } }","ref":"TaggedTuple.html#from_list/3","title":"TaggedTuple.from_list/3","type":"function"},{"doc":"Converts a map to a tagged tuple. The tag_fun will be invoked with each tag, and the result will be added to the tuple. The value_fun will be invoked with the core value, and the result will be added to the tuple. Examples iex&gt; TaggedTuple . from_map ( %{ a : %{ tag : %{ chain : 2 } } } ) { :a , { :tag , { :chain , 2 } } } iex&gt; TaggedTuple . from_map ( %{ &quot;a&quot; =&gt; %{ &quot;tag&quot; =&gt; %{ &quot;chain&quot; =&gt; 20 } } } , &amp; String . to_existing_atom / 1 , &amp; div ( &amp;1 , 10 ) ) { :a , { :tag , { :chain , 2 } } }","ref":"TaggedTuple.html#from_map/3","title":"TaggedTuple.from_map/3","type":"function"},{"doc":"Returns the tag chain and the core value from the given tagged tuple. Examples iex&gt; { chain , value } = TaggedTuple . split ( { :a , { :tag , { :chain , 2 } } } ) ...&gt; chain == { :a , { :tag , :chain } } ...&gt; value == 2 iex&gt; TaggedTuple . tag ( value , chain ) { :a , { :tag , { :chain , 2 } } }","ref":"TaggedTuple.html#split/1","title":"TaggedTuple.split/1","type":"function"},{"doc":"Returns a tagged tuple by attaching the tag chain to the core value. tag_chain can be a nested tuple with tags returned from the split/1 or a list with tags. Example iex&gt; TaggedTuple . tag ( 2.5 , :some_tag ) { :some_tag , 2.5 } iex&gt; TaggedTuple . tag ( 7 , { :a , { :tag , :chain } } ) { :a , { :tag , { :chain , 7 } } } iex&gt; TaggedTuple . tag ( 7 , [ :a , :tag , :chain ] ) { :a , { :tag , { :chain , 7 } } }","ref":"TaggedTuple.html#tag/2","title":"TaggedTuple.tag/2","type":"function"},{"doc":"Converts a tagged tuple to a list. The tag_fun will be invoked with each tag, and the result will be inserted into the list. The value_fun will be invoked with the tagged tuple's core value, and the result will be inserted into the list. Examples iex&gt; TaggedTuple . to_list ( { :a , { :tag , { :chain , 2 } } } ) [ :a , :tag , :chain , 2 ] iex&gt; TaggedTuple . to_list ( { :a , { :tag , { :chain , 2 } } } , &amp; to_string / 1 , &amp; ( &amp;1 * 100 ) ) [ &quot;a&quot; , &quot;tag&quot; , &quot;chain&quot; , 200 ]","ref":"TaggedTuple.html#to_list/3","title":"TaggedTuple.to_list/3","type":"function"},{"doc":"Converts a tagged tuple to a map. The returned map can be encoded into a JSON to transmit over the network or persist in a database. The tag_fun will be invoked with each tag, and the result will be inserted into the map. The value_fun will be invoked with the tagged tuple's core value, and the result will be inserted into the map. Examples iex&gt; TaggedTuple . to_map ( { :a , { :tag , { :chain , 2 } } } ) %{ a : %{ tag : %{ chain : 2 } } } iex&gt; TaggedTuple . to_map ( { :a , { :tag , { :chain , 2 } } } , &amp; to_string / 1 , &amp; ( &amp;1 * 100 ) ) %{ &quot;a&quot; =&gt; %{ &quot;tag&quot; =&gt; %{ &quot;chain&quot; =&gt; 200 } } }","ref":"TaggedTuple.html#to_map/3","title":"TaggedTuple.to_map/3","type":"function"},{"doc":"Same as untag!/2 . Returns {:error, :mismatch} when tag_chain doesn't match the beginning part of the tag chain of the tagged tuple.","ref":"TaggedTuple.html#untag/2","title":"TaggedTuple.untag/2","type":"function"},{"doc":"Removes the given subchain from the tag chain's beginning and return the tagged tuple built from the rest. When the full tag chain is given, it returns the core value. Raises ArgumentError exception if the passed tag subchain doesn't match the begginning of the tag chain of the tagged tuple. tag_chain can be a nested tuple with tags returned from the split/1 or a list with tags. Examples iex&gt; value = { :a , { :tag , { :chain , 2 } } } iex&gt; TaggedTuple . untag! ( value , :a ) { :tag , { :chain , 2 } } iex&gt; TaggedTuple . untag! ( value , { :a , :tag } ) { :chain , 2 } iex&gt; TaggedTuple . untag! ( value , { :a , { :tag , :chain } } ) 2 iex&gt; TaggedTuple . untag! ( value , [ :a , :tag , :chain ] ) 2 iex&gt; value = { :other , { :stuff , 2 } } ...&gt; TaggedTuple . untag! ( value , { :a , { :tag , :chain } } ) ** (ArgumentError) Tag chain {:a, {:tag, :chain}} doesn&#39;t match one in the tagged tuple {:other, {:stuff, 2}}.","ref":"TaggedTuple.html#untag!/2","title":"TaggedTuple.untag!/2","type":"function"}]